.. Inheritance Test documentation master file, created by
   sphinx-quickstart on Sun Nov 13 11:04:16 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Inheritance Test's documentation!
============================================

Contents:

.. toctree::
   :maxdepth: 2

   submodule2/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

